@@ -12,7 +12,7 @@ from ase import Atoms
 from ase.optimize import BFGS
 import ase.calculators.calculator
 try:
-    from ..batch_opt.ANI2xt import ANI2xt
+    from ..batch_opt.ANI2xt_no_rep import ANI2xt
 except:
     pass
 import torchani
