@@ -21,6 +21,6 @@ with warnings.catch_warnings():
         warnings.warn("TorchANI is not installed")
 
     try:
-        from .batch_opt.ANI2xt import ANI2xt
+        from .batch_opt.ANI2xt_no_rep import ANI2xt
     except:
         warnings.warn("ANI2xt model is not available")
